# PyCNNUM

Convert numbers in Chinese string to/from `int`/`float`/`str`.

<!-- omit in toc -->
## Thanks to all issue reports


```bash
python3.8 -m venv .venv
source .venv/bin/activate
python -m pip install pip -U
python -m pip install .[dev]
```
